@@ -1,6 +1,7 @@
 
 import glob
 import pkg_resources
+import shutil
 
 import yaml
 from lizard_languages import languages
@@ -43,12 +44,27 @@ def get_available_lizard_exts():
     return set(exts)
 
 
-def get_all_analysable_files(dirname, rule_sets):
+def get_available_exts(rule_sets):
     lizard_exts = get_available_lizard_exts()
-    exts = [ext for ext in lizard_exts if rule_sets.is_ext_available(ext)]
+    return [ext for ext in lizard_exts if rule_sets.is_ext_available(ext)]
+
+
+def get_all_analysable_files(dirname, rule_sets):
+    exts = get_available_exts(rule_sets)
 
     files = []
     for ext in exts:
         files.extend(glob.glob(fr'{dirname}/**/*.{ext}', recursive=True))
 
     return files
+
+
+def copy_default_rule(language, filename=None):
+    rule_name = MAP_DEFAULT_RULE_NAMES[language]
+
+    if filename is None:
+        filename = f'{rule_name}.yaml'
+
+    shutil.copy2(_get_default_rule_filename(rule_name), filename)
+
+    return filename
